Python: package durus

durus (version 3.9.1) | index /home/steiner/src/notmm/branches/0.4-stable/extras/libdurus/durus/__init__.py

`$URL: svn+ssh://svn.mems-exchange.org/repos/trunk/durus/__init__.py $
$Id: __init__.py 31554 2009-03-25 15:47:08Z dbinger $
Copyright (c) Corporation for National Research Initiatives 2009. All Rights Reserved.`

Package Contents
`` |  |
__main__ _persistent btree client_storage connection | db_renumber db_to_py3k error file file_storage | logger persistent persistent_dict persistent_list persistent_set | serialize shelf storage storage_server utils

Data
`` |  | __version__ = '3.9.1'